../../guestbin/ipsec-kernel-state.sh
../../guestbin/ipsec-kernel-policy.sh
# ==== cut ====
ipsec auto --status | grep westnet-eastnet-compress
# ==== tuc ====
